GenerativeConfig class sealed

Available extensions
Annotations
  • @freezed

Constructors

GenerativeConfig({required String model, List<SafetySetting>? safetySettings, GenerationConfig? generationConfig, List<FirebaseAiToolSchema>? toolSchemas, ToolingConfig? toolConfig, String? systemPrompt})
const
factory

Properties

copyWith → $GenerativeConfigCopyWith<GenerativeConfig>
Create a copy of GenerativeConfig with the given fields replaced by the non-null parameter values.
no setterinherited
generationConfig → GenerationConfig?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
model String
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
safetySettings List<SafetySetting>?
no setterinherited
systemPrompt String?
no setterinherited
toolConfig → ToolingConfig?
no setterinherited
toolSchemas List<FirebaseAiToolSchema>?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_GenerativeConfig value)) → TResult

Available on GenerativeConfig, provided by the GenerativeConfigPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_GenerativeConfig value)?) → TResult?

Available on GenerativeConfig, provided by the GenerativeConfigPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_GenerativeConfig value)?, {required TResult orElse()}) → TResult

Available on GenerativeConfig, provided by the GenerativeConfigPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String model, List<SafetySetting>? safetySettings, GenerationConfig? generationConfig, List<FirebaseAiToolSchema>? toolSchemas, ToolingConfig? toolConfig, String? systemPrompt)?, {required TResult orElse()}) → TResult

Available on GenerativeConfig, provided by the GenerativeConfigPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String model, List<SafetySetting>? safetySettings, GenerationConfig? generationConfig, List<FirebaseAiToolSchema>? toolSchemas, ToolingConfig? toolConfig, String? systemPrompt)) → TResult

Available on GenerativeConfig, provided by the GenerativeConfigPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String model, List<SafetySetting>? safetySettings, GenerationConfig? generationConfig, List<FirebaseAiToolSchema>? toolSchemas, ToolingConfig? toolConfig, String? systemPrompt)?) → TResult?

Available on GenerativeConfig, provided by the GenerativeConfigPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited